
/*******************************************************************************************************************

 (C) Copyright  Marvell Semiconductor Hefei branch Ltd. All Rights Reserved  
 // Use of OpenSSL API is governed by a BSD-style license 
 /* ====================================================================
 * Copyright (c) 1998-2011 The OpenSSL Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit. (http://www.openssl.org/)"
 *
 * 4. The names "OpenSSL Toolkit" and "OpenSSL Project" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    openssl-core@openssl.org.
 *
 * 5. Products derived from this software may not be called "OpenSSL"
 *    nor may "OpenSSL" appear in their names without prior written
 *    permission of the OpenSSL Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit (http://www.openssl.org/)"
 *
 * THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS'' AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.

 *******************************************************************************************************************/
#include "Macrodef.h"
#include "../WtptpDownLoad/ParaDefine.h"
#include "RndParadef.h"
#ifdef IFLSWD_STATIC
#include "BLFProperty.h"
#endif

#ifdef IFLSWD_DYNAMIC
#ifdef IFLSWD_EXPORTS
#define IFLSWD_FUNC extern "C" __declspec(dllexport)
#else
#define IFLSWD_FUNC extern "C" __declspec(dllimport)
#endif
#else
#define IFLSWD_FUNC
#endif


/*! @defgroup groupFunctions function list
* @{
*/
/// =========================================
/// @fn			ReadBLF(PInstanceParams PInstParam,char * pszBLFfileName)
/// @brief		Read and Parse blf file and generate temp folder for download
/// @param[in]	pszBLFfileName 
/// @param[out] PInstParam including download file list and DKB files name and other configurations.                                                                 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used in user only provide separated images to download\n
///
/// =========================================
IFLSWD_FUNC bool ReadBLF(PInstanceParams pInstParam,const TCHAR * pszBLFfileName);

/*! @defgroup groupFunctions function list
* @{
*/
/// =========================================
/// @fn			PrepareUpload(PInstanceParams PInstParam,char * pszUploadCfgfileName)
/// @brief		Read and Parse upload configuration file and do preparations
/// @param[in]	pszBLFfileName 
/// @param[out] PInstParam including download file list and DKB files name and other configurations.                                                                 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used to generate a Realiable data format file\n
///
/// =========================================
IFLSWD_FUNC bool PrepareUpload(PInstanceParams PInstParam,const TCHAR * pszUploadCfgfileName);
//#if !defined(LINUX)
/// =========================================
/// @fn			RNDBuilder(RNDEntryParams* pRNDEnParas, char *pszRNDfileName)
/// @brief		Generate a Reliable Data file 
/// @param[in]	pszRNDfileName 
/// @param[out] pRNDEnParas.                                                           
/// @details	User need to input files and enry type to pRNDEnParas 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		please see detail of structure of pRNDEnParas comments of each parameter\n 
///
/// =========================================
IFLSWD_FUNC bool  RNDBuilder(RNDEntryParams* pRNDEnParas, const TCHAR *pszRNDfileName);

//#endif

IFLSWD_FUNC bool RNDParser(const TCHAR *pszRNDfileName, const TCHAR *pszDestDir, list<FLASH_ENTRY_INFO>& flashEntryInfo);

/// =========================================
/// @fn			RRNDParser(const char *pszRNDfileName, FLASH_RD_PARSE* const pFlashRdParse)
/// @brief		Generate some bin files through parsing a Reliable Data file
/// @param[in]	pszRNDfileName 
/// @param[in]  pFlashRdParse                                                           
/// @details	User need to input  Reliable Data file name and structor FLASH_RD_PARSE type 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		please see detail of structure of FLASH_RD_PARSE comments of each parameter\n 
///
/// =========================================
//bool RNDParser(const char *pszRNDfileName, FLASH_RD_PARSE* const pFlashRdParse);

/// =========================================
/// @fn			SetMode(unsigned int Command)
/// @brief		Set User command
/// @param[in]	Command    
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is for reserved use\n
/// =========================================
IFLSWD_FUNC bool  SetMode(unsigned int Command);


/// =========================================
/// @fn			PrepareDownloadWithFBF(PInstanceParams PInstParam,char * pszBLFfileName ,char* pszFlasherfileName,char *pszFBFfileName)
/// @brief		Parse blf file and generate temp folder for download
/// @param[in]	pszBLFfileName 
/// @param[in]	pszFBFfileName 
/// @param[out] PInstParam including download file list and DKB files name and other configurations.     
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used in user only provide a prepared FBF file in production,\n
///				This API is better in production line,but user need to prepare FBF file first\n
///				How to Generate FBF file , there are two steps: \n
///				1, run NtimBuild.exe to generate a tim header file;\n
///				2, run FBF_Make.exe to generate a FBF file.\n
///
/// =========================================
IFLSWD_FUNC  bool PrepareDownloadWithFBF(PInstanceParams pInstParam,const TCHAR * pszBLFfileName ,const TCHAR* pszFlasherfileName,const TCHAR *pszFBFfileName);

/// =========================================
/// @fn			GetBlfInfo(char * pszBLFfileName,BlfInfoProperty* pBLFInfo)
/// @brief		Parse blf file and generate temp folder for download
/// @param[in]	pszBLFfileName 
/// @param[in]	pszFlasherfileName 
/// @param[in]	pszFBFfileName 
/// @param[out] pBLFInfo including all information of blf file.                                                                 
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used in user need to do modifications of configurations in blf file in their UI\n
///				This API is NOT recommend in production line tool, it is better use in development phase's tool\n
///				because it is too flexible \n 
///
/// =========================================

#ifdef IFLSWD_STATIC
bool  GetBlfInfo(const TCHAR * pszBLFfileName,BlfInfoProperty* pBLFInfo);
#endif

/// =========================================
/// @fn			SetBlfInfo(char * pszBLFfileName,BlfInfoProperty* pBLFInfo)
/// @brief		Parse blf file and generate temp folder for download
/// @param[in]	pszBLFfileName
/// @param[out] pBLFInfo including all information of blf file.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used in user have Modified configurations of blf file in their UI \n
///				and need to save those changes into blf file for future usage \n
///				This API is NOT recommend in production line tool, it is better use in development phase's tool\n
///				because it is too flexible \n
///
/// =========================================
#ifdef IFLSWD_STATIC
bool SetBlfInfo(const TCHAR * pszBLFfileName,BlfInfoProperty* pBLFInfo);
#endif
/// =========================================
/// @fn			DoFBFMakeforSplitImage(const char * pszBLFfileName,const char * pszSplitSize)
/// @brief		Parse blf file and make a special FBF file as user request that split an image to 
///             several images 
/// @param[in]	pszBLFfileName 
/// @param[in]	pszSplitSize 
/// @param[out] fbf.bin file.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		This function is used for speical case to split an large image to serveral images by splitsize user set and 
///				wrap all images into a fbf file \n
///
/// =========================================
IFLSWD_FUNC bool DoFBFMakeforSplitImage(const TCHAR * pszBLFfileName,const TCHAR * pszSplitSize);

/// =========================================
/// @fn			NTimBuilder(const char * pszBLFfileName)
/// @brief		Parse blf file and generate a tim file as the name described in blf file 
///             it will be have the same path as blf file
/// @param[in]	pszBLFfileName 
/// @param[out] tim file.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		this function is used to generate a tim/ntim file  \n
///
/// =========================================
IFLSWD_FUNC bool NTimBuilder(const TCHAR * pszBLFfileName);

/// =========================================
/// @fn			FBFMake(const char * pszBLFfileName,const char * pszFBFfileName)
/// @brief		Parse blf file and generate fbf file as user input 
///             it will be have the same path as blf file
/// @param[in]	pszBLFfileName 
/// @param[out] pszFBFfileName.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		this function is used to generate a FBF format file for preparedownloadwithFBF \n
///
/// =========================================
IFLSWD_FUNC bool  FBFMake(const TCHAR * pszBLFfileName,const TCHAR * pszFBFfileName);

/// =========================================
/// @fn			PInstanceParams IFLSWD_FUNC GetInstanceParams()
/// @brief		Malloc memory for  PInstanceParams to let user use
///             it will return a pointer
/// @param[in]	NULL 
/// @param[out] PInstanceParams.                                                             
/// @return		bool.
///				@retval non NULL : Successfully .  
///				@retval NULL : Failed .
/// @note		this function is used to new a PInstanceParams to save parameters for use \n
///
/// =========================================
IFLSWD_FUNC  PInstanceParams MallocInstanceParams();


/// =========================================
/// @fn			bool MakeDownloadPackageWithRSA(const TCHAR* pszBlfFileName,char* pTimRSA,char* pDTimRSA)
/// @brief		Parse blf file, process images and parse blf file and Prepare download zip package
///  
/// @param[in]	pTimRSA , it is a pointer to a RSA stucture of openssl
/// @param[in]	pDTimRSA , it is a pointer to a RSA stucture of openssl 
/// @param[in]	pszBlfFileName 
/// @param[out] null.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		
///
/// =========================================
IFLSWD_FUNC bool MakeDownloadPackageWithRSA(const TCHAR* pszBlfFileName,char* pTimRSA,char* pDTimRSA);

/// =========================================
/// @fn			bool MakeDownloadPackage(const TCHAR* pszBlfFileName)
/// @brief		Parse blf file, process images and parse blf file and Prepare download zip package
///             
/// @param[in]	pszBlfFileName 
/// @param[out] null.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		
///
/// =========================================
IFLSWD_FUNC bool MakeDownloadPackage(const TCHAR* pszBlfFileName);

/// =========================================
/// @fn			 bool DownloadWithPackage(const TCHAR* pszDownloadPackagePath,PInstanceParams pInstParam)
/// @brief		 initial PInstanceParams from Download Zip Package
///
/// @param[in]	pszDownloadPackagePath 
/// @param[out] pInstParam.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		
///
/// =========================================

IFLSWD_FUNC bool DownloadWithPackage(const TCHAR* pszDownloadPackagePath,PInstanceParams pInstParam);


/// =========================================
/// @fn			bool IFLSWD_FUNC FreeInstanceParams(PInstanceParams pInstParam)
/// @brief		Free memory for  PInstanceParams to let user use
/// @param[in]	NULL 
/// @param[out] PInstanceParams.                                                             
/// @return		bool.
///				@retval true : Successfully .  
///				@retval false : Failed .
/// @note		this function is used to free a PInstanceParams to save parameters for use \n
///
/// =========================================
IFLSWD_FUNC bool FreeInstanceParams(PInstanceParams pInstParam);
///@}		//@defgroup groupFunctions function list


//
//#ifdef  __cplusplus
//}
//#endif
